@@ -24,15 +24,14 @@ class CustomS3JsonWriter:
         else:
             self.boto3_session = boto3.Session(profile_name=profile_name)
 
-        self.s3_resource = self.boto3_session.resource('s3')
+        self.s3_resource = self.boto3_session.resource("s3")
 
     def write_to_s3(self, json_data):
         """
-            Writes json data to s3 and names it by
-            date of writing.
+        Writes json data to s3 and names it by
+        date of writing.
         """
-        now = datetime.now().strftime('%Y_%m_%d_%H%M%S')
-        key_path = f'{os.path.join(self.file_path, now)}.json'
+        now = datetime.now().strftime("%Y_%m_%d_%H%M%S")
+        key_path = f"{os.path.join(self.file_path, now)}.json"
 
-        self.s3_resource.Object(self.bucket, key_path) \
-            .put(Body=json.dumps(json_data))
+        self.s3_resource.Object(self.bucket, key_path).put(Body=json.dumps(json_data))
