@@ -7,56 +7,52 @@ import pandas as pd
 import yaml
 
 
-def _prepare_chunked_dates(
-        start_date: str,
-        end_date: str,
-        day_freq: int
-):
+def _prepare_chunked_dates(start_date: str, end_date: str, day_freq: int):
     """
-        Split up dates in to multiple startDate, endDate pairs which are dayFreq apart
-        args:
-            start_date (str) : startDate of date range
-            end_date (str) : endDate of date range
-            day_freq (int)  : gap between startDate, endDate within each pairs
-        return:
-            dateRanges (list of dict)
+    Split up dates in to multiple startDate, endDate pairs which are dayFreq apart
+    args:
+        start_date (str) : startDate of date range
+        end_date (str) : endDate of date range
+        day_freq (int)  : gap between startDate, endDate within each pairs
+    return:
+        dateRanges (list of dict)
     """
     dates = pd.Series(pd.date_range(start=start_date, end=end_date))
-    date_freq = dates.groupby(np.arange(len(dates)) // day_freq).agg(
-        ['first', 'last'])
-    return date_freq.rename(
-        columns={
-            'first': 'startDate',
-            'last': 'endDate'}).astype(str).to_dict('records')
+    date_freq = dates.groupby(np.arange(len(dates)) // day_freq).agg(["first", "last"])
+    return (
+        date_freq.rename(columns={"first": "startDate", "last": "endDate"})
+        .astype(str)
+        .to_dict("records")
+    )
 
 
 def _restructure_date_ranges(config):
     """
-        Restructure dateRanges in to multiple pairs gapped by dayFreq
-        args:
-            config (dict): config file containing dayFreq, dateRanges keys
-        return:
-            config (dict)
+    Restructure dateRanges in to multiple pairs gapped by dayFreq
+    args:
+        config (dict): config file containing dayFreq, dateRanges keys
+    return:
+        config (dict)
     """
     # dynamic get kwargs or else set to default
-    day_freq = config.pop('dayFreq', '1d')
-    start_date = config.get('dateRanges', [])[0].get('startDate', None)
-    end_date = config.get('dateRanges', [])[0].get('endDate', None)
+    day_freq = config.pop("dayFreq", "1d")
+    start_date = config.get("dateRanges", [])[0].get("startDate", None)
+    end_date = config.get("dateRanges", [])[0].get("endDate", None)
     # restructure dateRanges
     date_ranges = _prepare_chunked_dates(start_date, end_date, day_freq)
     # update dateRanges in config
-    config.update({'dateRanges': date_ranges})
+    config.update({"dateRanges": date_ranges})
     return config
 
 
 # pylint: disable=invalid-name, unused-argument
 def _generate_queries(
-        viewIDs: list,
-        queryConfig: list,
-        dateRanges: list,
-        pageSize: int = 10000,
-        samplingLevel: str = 'LARGE',
-        **kwargs
+    viewIDs: list,
+    queryConfig: list,
+    dateRanges: list,
+    pageSize: int = 10000,
+    samplingLevel: str = "LARGE",
+    **kwargs
 ):
     """
     Use the Analytics Service Object to query the
@@ -76,11 +72,12 @@ def _generate_queries(
             for date_range in dateRanges:
                 print("creating a [fields] query")
                 fields = {
-                    'viewId': vid,
-                    'dateRanges': date_range,
+                    "viewId": vid,
+                    "dateRanges": date_range,
                     **single_query,
                     "samplingLevel": samplingLevel,
-                    "pageSize": pageSize}
+                    "pageSize": pageSize,
+                }
                 # building similar queries per vid
                 yield [fields]
 
@@ -88,20 +85,20 @@ def _generate_queries(
 def _parser(file_name):
     """Parse config in to dictionary"""
     # load config
-    with open(file_name, 'r') as file_:
+    with open(file_name, "r") as file_:
         return yaml.safe_load(file_)
 
 
 class GAConfigManager:
     """
-        Class that parses config .yaml for queries, reader, writer
-        Uses these configs to build required query objects.
+    Class that parses config .yaml for queries, reader, writer
+    Uses these configs to build required query objects.
     """
 
     def __init__(self, file_name):
         # load config
         self.config = _parser(file_name=file_name)
-        if self.config.pop('chunk_date_range', False):
+        if self.config.pop("chunk_date_range", False):
             self.config = _restructure_date_ranges(self.config)
         # get query generator
         self.query_gen, self.additional_args = self._builder(self.config)
@@ -111,11 +108,11 @@ class GAConfigManager:
         additional_args = {}
         # get metadata
         metadata = {
-            'dateRanges': self.config.get('dateRanges', None),
-            'samplingLevel': self.config.get('samplingLevel', None),
-            'pageSize': self.config.get('pageSize', None)
+            "dateRanges": self.config.get("dateRanges", None),
+            "samplingLevel": self.config.get("samplingLevel", None),
+            "pageSize": self.config.get("pageSize", None),
         }
-        additional_args.update({'metadata': metadata})
+        additional_args.update({"metadata": metadata})
         return _generate_queries(**config), additional_args
 
     def get_query(self):
